netapp_ontap.models.fc_login_initiator API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_login_initiator`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcLoginInitiatorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcLoginInitiator object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aliases: List[str] GET`

    The logged in initiator world wide port name (WWPN) aliases.

  `comment: str GET`

    A comment available for use by the administrator. This is modifiable from the initiator REST endpoint directly. See `PATCH /protocols/san/igroups/{igroup.uuid}/initiators/{name}`.

    Example: This is an FC initiator for host 5

  `port_address: str GET`

    The port address of the initiator's FC port.
    Each port in an FC switched fabric has its own unique port address for routing purposes. The port address is assigned by a switch in the fabric when that port logs in to the fabric. This property refers to the address given by a switch to the initiator port.
    This is useful for obtaining statistics and diagnostic information from FC switches.
    This is a hexadecimal encoded numeric value.

    Example: 5060A

  `wwnn: str GET`

    The logged in initiator world wide node name (WWNN).

    Example: 2f:a0:00:a0:98:0b:56:13

  `wwpn: str GET`

    The logged in initiator WWPN.

    Example: 2f:a0:00:a0:98:0b:56:13